package info.textgrid.middleware;

import org.elasticsearch.action.get.GetRequestBuilder;
import org.elasticsearch.action.get.GetResponse;

import info.textgrid.middleware.oaipmh.ListMetadataFormatsType;
import info.textgrid.middleware.oaipmh.MetadataFormatType;
import info.textgrid.middleware.oaipmh.RequestType;

public class MetadataFormatListDeliverer {
	
	private boolean idExist = true;
	private OAI_ESClient oaiEsClient;
	
	public MetadataFormatListDeliverer(OAI_ESClient oaiEsClient){
		this.oaiEsClient=oaiEsClient;
	}
		
	public ListMetadataFormatsType setMetadataFormatList(String id){
			
		ListMetadataFormatsType lmft = new ListMetadataFormatsType();
		MetadataFormatType mft = new MetadataFormatType();
		
		GetRequestBuilder recordById = oaiEsClient.getOaiESClient().prepareGet()
			.setIndex(oaiEsClient.getEsIndex())
			.setType(oaiEsClient.getEsType())
			.setFields("textgridUri")
			.setId(id); 
		
		GetResponse tgObject = recordById.execute().actionGet();
		
		if(tgObject.isExists()){
			setIdExist(true);
			mft.setMetadataNamespace("http://www.openarchives.org/OAI/2.0/oai_dc/");
			mft.setMetadataPrefix(TGConstants.METADATA_DC_PREFIX);
			mft.setSchema("http://www.openarchives.org/OAI/2.0/oai_dc.xsd");
			lmft.getMetadataFormat().add(mft);
		}else{
			setIdExist(false);
			lmft=null;
		}
				
		return lmft;
	}
	
	public ListMetadataFormatsType setMetadataFormatListWithoutId(){
		
		ListMetadataFormatsType lmft = new ListMetadataFormatsType();
		MetadataFormatType mft = new MetadataFormatType();
		
		mft.setMetadataNamespace("http://www.openarchives.org/OAI/2.0/oai_dc/");
		mft.setMetadataPrefix(TGConstants.METADATA_DC_PREFIX);
		mft.setSchema("http://www.openarchives.org/OAI/2.0/oai_dc.xsd");
		lmft.getMetadataFormat().add(mft);
		
		return lmft;
		
	}
	
	public boolean requestChecker(RequestType request){
		boolean requestCheck = true;
		
		if(request.getFrom()!=null ||
		   request.getMetadataPrefix()!=null ||
		   request.getResumptionToken()!=null){
			
			requestCheck = false;
			
		}else if(request.getSet()!=null ||
				 request.getUntil()!=null){
			requestCheck = false;
		}
		
		return requestCheck;
		
	}
	
	public boolean isIdExist() {
		return idExist;
	}

	public void setIdExist(boolean idExist) {
		this.idExist = idExist;
	}
	
}
