package info.textgrid.middleware;

import java.util.ArrayList;
import java.util.List;
import info.textgrid.middleware.oaipmh.RequestType;

/**
 * FIXME
 * 
 * @author Maximilian Brodhun, SUB Göttingen
 * @author Stefan E. Funk, SUB Göttingen
 * @version 2019-03-07
 * @since 2019-03-07
 */

public abstract class RecordDelivererAbstract implements RecordDelivererInterface {

  protected boolean textgrid;
  protected boolean dariah;

  /**
   * @param textgrid
   * @param dariah
   */
  public RecordDelivererAbstract(boolean textgrid, boolean dariah) {
    this.textgrid = textgrid;
    this.dariah = dariah;
  }

  /*
   * (non-Javadoc)
   * 
   * @see info.textgrid.middleware.RecordDelivererInterface#requestChecker(info.textgrid.middleware.
   * oaipmh.RequestType)
   */
  public static ErrorHandler requestChecker(RequestType request) {

    ErrorHandler result = new ErrorHandler();

    // Check if metadata prefix is existing and valid.
    if (request.getMetadataPrefix() != null
        && !request.getMetadataPrefix().equals(TGConstants.METADATA_DC_PREFIX)
        && !request.getMetadataPrefix().equals(TGConstants.METADATA_IDIOM_PREFIX)) {
      result.setError(TGConstants.OAI_METADATA_FORMAT_ERROR,
          "The value of the metadataPrefix: " + request.getMetadataPrefix()
              + " is not supported by the item identified by the value of: "
              + request.getIdentifier());
    }

    // Check if other params are existing, they shouldn't!
    else {

      List<String> errorValues = new ArrayList<String>();
      if (request.getFrom() != null) {
        errorValues.add("from");
      }
      if (request.getResumptionToken() != null) {
        errorValues.add("resumptionToken");
      }
      if (request.getSet() != null) {
        errorValues.add("set");
      }
      if (request.getUntil() != null) {
        errorValues.add("until");
      }
      if (request.getMetadataPrefix() == null) {
        errorValues.add("metadataPrefix");
      }
      if (request.getIdentifier() == null) {
        errorValues.add("identifier");
      }
      if(errorValues.size()>0) {
          result.setError(TGConstants.OAI_BAD_ARGUMENT, "The request includes illegal arguments "
                  + "or is missing required arguments: " + errorValues);
      }

    }

    return result;
  }

}
